==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/ruleoptionplugins/custom_option/kmfruleoptioneditcustom.cpp <==
/***************************************************************************
    Copyright (C) 2004 Christian Hubinger
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
//
// C++ Implementation: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@gmail.com>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kmfruleoptioneditcustom.h"



// QT includes
#include <qstring.h>

// KDE includes
#include <kdebug.h>
#include <klocale.h>
#include <kparts/genericfactory.h>

// Project includes
#include "../../core/iptrule.h"
#include "../../interfaces/kmfruleeditinterface.h"
#include "kmfruleeditcustomopt.h"


KMFRuleOptionEditCustom::KMFRuleOptionEditCustom(QObject *parent, const char *name,const QStringList& )
		: KMFRuleOptionEditInterface(parent, name) {
	kdDebug() <<"KMFRuleOptionEditCustom::KMFRuleOptionEditCustom(QObject *parent, const char *name)" << endl;
	kdDebug() << "Parent has Type: " << parent->className()  << endl;
	
	m_edit = new KMFRuleEditCustomOpt( 0 , "Edit" );
	m_edit->hide();

	connect( m_edit,SIGNAL(sigAddRuleOpt(QString*, QPtrList< QString >* ) ), 
		this,SLOT( slotAddRuleOption(QString*, QPtrList< QString >* ) ) );
	connect( m_edit,SIGNAL(sigAddTargetOpt(QString*, QPtrList< QString >* ) ), 
		this,SLOT( slotAddTargetOption(QString*, QPtrList< QString >* ) ) );
	connect( m_edit,SIGNAL(sigHideMe() ), 
		this,SLOT( slotShowOverview() ) );
}
KMFRuleOptionEditCustom::~KMFRuleOptionEditCustom() {}

void KMFRuleOptionEditCustom::slotAddRuleOption(QString* name, QPtrList< QString >* values ) {
	if ( KMFRuleEditInterface* ruleedit = dynamic_cast<KMFRuleEditInterface*> ( parent() ) ) {
		ruleedit->addRuleOption( name, values );
	} else {
		kdDebug() << "KMFRuleOptionEditCustom::slotAddRuleOption(): parent() not of type KMFRuleEditInterface" << endl;
	}
}
void KMFRuleOptionEditCustom::slotAddTargetOption(QString* name, QPtrList< QString >* values ) {
	if ( KMFRuleEditInterface* ruleedit = dynamic_cast<KMFRuleEditInterface*> ( parent() ) ) {
		ruleedit->addRuleTargetOption( name, values );
	} else {
		kdDebug() << "KMFRuleOptionEditCustom::slotAddTargetOption(): parent() not of type KMFRuleEditInterface" << endl;
	}
}
void KMFRuleOptionEditCustom::slotShowOverview() {
	if ( KMFRuleEditInterface* ruleedit = dynamic_cast<KMFRuleEditInterface*> ( parent() ) ) {
		ruleedit->showOverview();
	} else {
		kdDebug() << "KMFRuleOptionEditCustom::slotShowOverview(): parent() not of type KMFRuleEditInterface" << endl;
	}
}

const QString& KMFRuleOptionEditCustom::optionEditName() const {
	return *( new QString( i18n("Custom Option") ) );
}
const QString& KMFRuleOptionEditCustom::description() const {
	return *( new QString( i18n("This plugin manages the Custom options.") ) );
}

void KMFRuleOptionEditCustom::loadRule( IPTRule* rule ) {
	if ( !rule ) {
		kdDebug() << "KMFRuleOptionEditCustom::loadRule( IPTRule* rule ) - rule == 0" << endl;
		return;
	}
	
	m_edit->loadRule( rule );
	m_rule = rule;

}

QWidget* KMFRuleOptionEditCustom::editWidget() {
	if ( ! m_edit ) {
		kdDebug() << "KMFRuleOptionEditCustom::editWidget() - m_edit == 0" << endl;
		return 0;
	}
	return m_edit;
}





// It's usually safe to leave the factory code alone.. with the
// notable exception of the KAboutData data
#include <kaboutdata.h>
#include <klocale.h>

// // KInstance* KMFRuleOptionEditCustomFactory::s_instance = 0L;
// // KAboutData* KMFRuleOptionEditCustomFactory::s_about = 0L;

KMFRuleOptionEditCustomFactory::KMFRuleOptionEditCustomFactory( QObject* parent, const char* name )
		: KLibFactory( parent, name ) {
// // 	s_instance = new KInstance( "KMFRuleOptionEditCustomFactory" );
}

QObject* KMFRuleOptionEditCustomFactory::createObject( QObject* parent, const char* name,
        const char*, const QStringList & ) {
	QObject * obj = new KMFRuleOptionEditCustom( parent, name );
	emit objectCreated( obj );
	return obj;
}


// // KInstance* KMFRuleOptionEditCustomFactory::instance() {
// // 	if ( !s_instance ) {
// // 		s_instance = new KInstance( "KMFRuleOptionEditCustomFactory" );
// // 	}
// // 	return s_instance;
// // }

extern "C" {
	void* init_libkmfruleoptionedit_custom() {
		return new KMFRuleOptionEditCustomFactory;
	}
}




#include "kmfruleoptioneditcustom.moc"

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/ruleoptionplugins/custom_option/kmfruleoptioneditcustom.cpp <==
/***************************************************************************
    Copyright (C) 2004 Christian Hubinger
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
//
// C++ Implementation: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kmfruleoptioneditcustom.h"



// QT includes
#include <qstring.h>

// KDE includes
#include <kdebug.h>
#include <klocale.h>
#include <kparts/genericfactory.h>

// Project includes
#include "../../core/iptrule.h"
#include "../../core/kmfruleeditinterface.h"
#include "kmfruleeditcustomopt.h"

namespace KMF {
KMFRuleOptionEditCustom::KMFRuleOptionEditCustom(QObject *parent, const char *name,const QStringList& )
		: KMFRuleOptionEditInterface(parent, name) {
	kdDebug() <<"KMFRuleOptionEditCustom::KMFRuleOptionEditCustom(QObject *parent, const char *name)" << endl;
	kdDebug() << "Parent has Type: " << parent->className()  << endl;
	
	m_edit = new KMFRuleEditCustomOpt( 0 , "Edit" );
	m_edit->hide();
	
	connect( m_edit,SIGNAL(sigHideMe() ), 
		this,SLOT( slotShowOverview() ) );
}
KMFRuleOptionEditCustom::~KMFRuleOptionEditCustom() {}

void KMFRuleOptionEditCustom::slotShowOverview() {
	if ( KMFRuleEditInterface* ruleedit = dynamic_cast<KMFRuleEditInterface*> ( parent() ) ) {
		ruleedit->showOverview();
	} else {
		kdDebug() << "KMFRuleOptionEditCustom::slotShowOverview(): parent() not of type KMFRuleEditInterface" << endl;
	}
}

const QString& KMFRuleOptionEditCustom::optionEditName() const {
	return *( new QString( i18n("Custom Option") ) );
}
const QString& KMFRuleOptionEditCustom::description() const {
	return *( new QString( i18n("This plugin manages the Custom options.") ) );
}

void KMFRuleOptionEditCustom::loadRule( IPTRule* rule ) {
	if ( !rule ) {
		kdDebug() << "KMFRuleOptionEditCustom::loadRule( IPTRule* rule ) - rule == 0" << endl;
		return;
	}
	
	m_edit->loadRule( rule );
	m_rule = rule;

}

QWidget* KMFRuleOptionEditCustom::editWidget() {
	if ( ! m_edit ) {
		kdDebug() << "KMFRuleOptionEditCustom::editWidget() - m_edit == 0" << endl;
		return 0;
	}
	return m_edit;
}





// It's usually safe to leave the factory code alone.. with the
// notable exception of the KAboutData data
#include <kaboutdata.h>
#include <klocale.h>

// // KInstance* KMFRuleOptionEditCustomFactory::s_instance = 0L;
// // KAboutData* KMFRuleOptionEditCustomFactory::s_about = 0L;

KMFRuleOptionEditCustomFactory::KMFRuleOptionEditCustomFactory( QObject* parent, const char* name )
		: KLibFactory( parent, name ) {
// // 	s_instance = new KInstance( "KMFRuleOptionEditCustomFactory" );
}

QObject* KMFRuleOptionEditCustomFactory::createObject( QObject* parent, const char* name,
        const char*, const QStringList & ) {
	QObject * obj = new KMFRuleOptionEditCustom( parent, name );
	emit objectCreated( obj );
	return obj;
}


// // KInstance* KMFRuleOptionEditCustomFactory::instance() {
// // 	if ( !s_instance ) {
// // 		s_instance = new KInstance( "KMFRuleOptionEditCustomFactory" );
// // 	}
// // 	return s_instance;
// // }

extern "C" {
	void* init_libkmfruleoptionedit_custom() {
		return new KMFRuleOptionEditCustomFactory;
	}
}


}

#include "kmfruleoptioneditcustom.moc"
